==> apache-camel-4.10.9-src.zip: apache-camel-4.10.9/components/camel-beanio/src/main/java/org/apache/camel/dataformat/beanio/BeanIOHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.beanio;

import java.util.List;

import org.apache.camel.Exchange;
import org.apache.camel.util.ObjectHelper;
import org.beanio.BeanReaderErrorHandler;

/**
 * Helper class
 */
public final class BeanIOHelper {

    private BeanIOHelper() {
        // utility class
    }

    public static BeanReaderErrorHandler getOrCreateBeanReaderErrorHandler(
            BeanIOConfiguration configuration, Exchange exchange,
            List<Object> results, BeanIOIterator iterator)
            throws Exception {
        BeanReaderErrorHandler answer = null;

        if (ObjectHelper.isNotEmpty(configuration.getBeanReaderErrorHandlerType())) {
            Class<?> clazz = exchange.getContext().getClassResolver()
                    .resolveMandatoryClass(configuration.getBeanReaderErrorHandlerType());
            Object instance = exchange.getContext().getInjector().newInstance(clazz);
            answer = (BeanReaderErrorHandler) instance;
        }
        if (answer == null && ObjectHelper.isNotEmpty(configuration.getBeanReaderErrorHandler())) {
            answer = configuration.getBeanReaderErrorHandler();
        }
        if (answer == null) {
            answer = new BeanIOErrorHandler();
        }
        // if the error handler extends BeanIOErrorHandler then its prototype scoped
        // and then inject the current exchange and init
        if (answer instanceof BeanIOErrorHandler) {
            BeanIOErrorHandler eh = (BeanIOErrorHandler) answer;
            eh.setConfiguration(configuration);
            eh.setExchange(exchange);
            eh.setResults(results);
            eh.setIterator(iterator);
            eh.init();
        }

        return answer;
    }

}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/components/camel-beanio/src/main/java/org/apache/camel/dataformat/beanio/BeanIOHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.dataformat.beanio;

import java.util.List;

import org.apache.camel.Exchange;
import org.apache.camel.util.ObjectHelper;
import org.beanio.BeanReaderErrorHandler;

/**
 * Helper class
 */
public final class BeanIOHelper {

    private BeanIOHelper() {
        // utility class
    }

    public static BeanReaderErrorHandler getOrCreateBeanReaderErrorHandler(
            BeanIOConfiguration configuration, Exchange exchange,
            List<Object> results, BeanIOIterator iterator)
            throws Exception {
        BeanReaderErrorHandler answer = null;

        if (ObjectHelper.isNotEmpty(configuration.getBeanReaderErrorHandlerType())) {
            Class<?> clazz = exchange.getContext().getClassResolver()
                    .resolveMandatoryClass(configuration.getBeanReaderErrorHandlerType());
            Object instance = exchange.getContext().getInjector().newInstance(clazz);
            answer = (BeanReaderErrorHandler) instance;
        }
        if (answer == null && ObjectHelper.isNotEmpty(configuration.getBeanReaderErrorHandler())) {
            answer = configuration.getBeanReaderErrorHandler();
        }
        if (answer == null) {
            answer = new BeanIOErrorHandler();
        }
        // if the error handler extends BeanIOErrorHandler then its prototype scoped
        // and then inject the current exchange and init
        if (answer instanceof BeanIOErrorHandler eh) {
            eh.setConfiguration(configuration);
            eh.setExchange(exchange);
            eh.setResults(results);
            eh.setIterator(iterator);
            eh.init();
        }

        return answer;
    }

}
